@@ -48,10 +48,10 @@ tar_skip <- function(
   retrieval = targets::tar_option_get("retrieval"),
   cue = targets::tar_option_get("cue")
 ) {
-  name <- deparse_language(substitute(name))
+  name <- targets::tar_deparse_language(substitute(name))
   envir <- tar_option_get("envir")
-  command <- tar_tidy_eval(substitute(command), envir, tidy_eval)
-  skip <- tar_tidy_eval(substitute(skip), envir, tidy_eval)
+  command <- targets::tar_tidy_eval(substitute(command), envir, tidy_eval)
+  skip <- targets::tar_tidy_eval(substitute(skip), envir, tidy_eval)
   skip <- as.call(list(call_ns("targets", "tar_cancel"), skip))
   command <- call_brace(list(skip, command))
   targets::tar_target_raw(
